pyprocar.plotter.DOSPlot — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.plotter.DOSPlot

class pyprocar.plotter.DOSPlot(dos: DensityOfStates | None = None, structure: Structure | None = None, ax: Axes | None = None, orientation: str = 'horizontal', config=None)

  Class to plot an electronic band structure.

  Parameters:

    - dos (DensityOfStates) – An density of states pyprocar.core.DensityOfStates.

    - structure (Structure) – An density of states pyprocar.core.Structure.

    - ax (mpl.axes.Axes, optional) – A matplotlib Axes object. If provided the plot will be located at that ax. The default is None.

  Returns:

    None.

  Methods

  `DOSPlot.__init__`([dos, structure, ax, ...]) |
  `DOSPlot.draw_fermi`(value[, orientation]) | A method to draw the fermi surface
  `DOSPlot.export_data`(filename) | This method will export the data to a csv file
  `DOSPlot.grid`() | A method to include a grid on the plot.
  `DOSPlot.legend`([labels]) | A method to include the legend
  `DOSPlot.plot_dos`([spins]) |
  `DOSPlot.plot_parametric`([atoms, orbitals, ...]) |
  `DOSPlot.plot_parametric_line`([atoms, ...]) |
  `DOSPlot.plot_stack`([items, ...]) |
  `DOSPlot.plot_stack_orbitals`([...]) |
  `DOSPlot.plot_stack_species`([...]) |
  `DOSPlot.save`([filename]) | A method to save the plot
  `DOSPlot.set_xlabel`(label) | A method to set the x label
  `DOSPlot.set_xlim`([interval]) | A method to set the xlim of the plot
  `DOSPlot.set_xticks`([tick_positions, tick_names]) | A method to set the xticks of the plot
  `DOSPlot.set_ylabel`(label) | A method to set the y label
  `DOSPlot.set_ylim`([interval]) | A method to set the ylim of the plot
  `DOSPlot.set_yticks`([tick_positions, tick_names]) | A method to set the yticks of the plot
  `DOSPlot.show`() | A method to show the plot
  `DOSPlot.update_config`(config_dict) |